@@ -34,6 +34,21 @@ _html_context_data = None
 logger = logging.getLogger(__name__)
 
 
+def _has_stable_branches():
+    try:
+        repo = dulwich.repo.Repo.discover()
+    except dulwich.repo.NotGitRepository:
+        return False
+
+    refs = repo.get_refs()
+    for ref in refs.keys():
+        ref = ref.decode('utf-8')
+        if ref.startswith('refs/remotes/origin/stable'):
+            return True
+
+    return False
+
+
 def _get_other_versions(app):
     if not app.config.html_theme_options.get('show_other_versions', False):
         return []
@@ -110,6 +125,11 @@ def _html_page_context(app, pagename, templatename, context, doctree):
         bug_project = app.config.bug_project
         if bug_project:
             _html_context_data['bug_project'] = bug_project
+        use_storyboard = app.config.use_storyboard
+        if bug_project and use_storyboard:
+            _html_context_data['use_storyboard'] = use_storyboard
+        # Previously storyboard showed numbers that were used, keep
+        # for old conf.py files:
         if bug_project and bug_project.isdigit():
             _html_context_data['use_storyboard'] = True
         bug_tag = app.config.bug_tag
@@ -117,6 +137,21 @@ def _html_page_context(app, pagename, templatename, context, doctree):
             _html_context_data['bug_tag'] = bug_tag
         _html_context_data['series'] = _get_series_name()
 
+        # Do not show the badge in these cases:
+        # - display_badge is false
+        # - repo has no stable/ branches
+        # - directory is named api-guide, api-ref, or releasenotes
+        if not app.config.html_theme_options.get('display_badge', True):
+            _html_context_data['display_badge'] = False
+        elif _has_stable_branches():
+            doc_parts = os.path.abspath(app.srcdir).split(os.sep)[-2:]
+            if doc_parts[0] in ('api-guide', 'api-ref', 'releasenotes'):
+                _html_context_data['display_badge'] = False
+            else:
+                _html_context_data['display_badge'] = True
+        else:
+            _html_context_data['display_badge'] = False
+
     context.update(_html_context_data)
     context['other_versions'] = _get_other_versions(app)
 
@@ -262,6 +297,7 @@ def setup(app):
     app.add_config_value('bug_project', '', 'env')
     app.add_config_value('bug_tag', '', 'env')
     app.add_config_value('openstack_projects', [], 'env')
+    app.add_config_value('use_storyboard', '', 'env')
     app.add_html_theme(
         'openstackdocs',
         os.path.abspath(os.path.dirname(__file__)) + '/theme/openstackdocs',
